==> haskell-stringsearch-0.3.6.6-5-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-stringsearch.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: stringsearch
version: 0.3.6.6
id: stringsearch-0.3.6.6-K30MyFaBEiEDdRa9SPnW19
key: stringsearch-0.3.6.6-K30MyFaBEiEDdRa9SPnW19
license: BSD3
copyright: (c) 2007-2011
           Daniel Fischer, Chris Kuklewicz, Justin Bailey
maintainer: daniel.is.fischer@googlemail.com
homepage: https://bitbucket.org/dafis/stringsearch
synopsis: Fast searching, splitting and replacing of ByteStrings
description:
    This package provides several functions to quickly
    search for substrings in strict or lazy ByteStrings.
    It also provides functions for breaking or splitting
    on substrings and replacing all occurrences of a
    substring (the first in case of overlaps) with another.
    GHC before 6.10 are no longer supported, other compilers
    only if they support BangPatterns. If you need it to
    work with other compilers, send a feature request.
category: Text, Search
author: Daniel Fischer, Chris Kuklewicz, Justin Bailey
exposed: True
indefinite: False
exposed-modules:
    Data.ByteString.Lazy.Search Data.ByteString.Lazy.Search.DFA
    Data.ByteString.Lazy.Search.KMP
    Data.ByteString.Lazy.Search.KarpRabin Data.ByteString.Search
    Data.ByteString.Search.BoyerMoore Data.ByteString.Search.DFA
    Data.ByteString.Search.KMP Data.ByteString.Search.KarpRabin
    Data.ByteString.Search.KnuthMorrisPratt
    Data.ByteString.Search.Substitution
hidden-modules: Data.ByteString.Search.Internal.BoyerMoore
                Data.ByteString.Search.Internal.KnuthMorrisPratt
                Data.ByteString.Search.Internal.Utils
                Data.ByteString.Lazy.Search.Internal.BoyerMoore
abi: 648bb620478d7cfe1abc1c1686592bc7
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/stringsearch-0.3.6.6
library-dirs: /usr/lib/ghc-8.2.1/site-local/stringsearch-0.3.6.6
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.1/stringsearch-0.3.6.6
hs-libraries: HSstringsearch-0.3.6.6-K30MyFaBEiEDdRa9SPnW19
depends:
    array-0.5.2.0 base-4.10.0.0 bytestring-0.10.8.2 containers-0.5.10.2
abi-depends: array-0.5.2.0=f1e5b16bbab6fd27896e28be963fa7eb
             base-4.10.0.0=835a16347ec1b210054efd02671c29ee
             bytestring-0.10.8.2=590a7a3c0bdcf7a6a59d8c8ef548a44a
             containers-0.5.10.2=dd4e66fa9ac268f47a15786f1100b042
haddock-interfaces: /usr/share/doc/haskell-stringsearch/html/stringsearch.haddock
haddock-html: /usr/share/doc/haskell-stringsearch/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-stringsearch-0.3.6.6-6-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-stringsearch.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: stringsearch
version: 0.3.6.6
id: stringsearch-0.3.6.6-5wkiVsEYY78BZshzFV6bBe
key: stringsearch-0.3.6.6-5wkiVsEYY78BZshzFV6bBe
license: BSD3
copyright: (c) 2007-2011
           Daniel Fischer, Chris Kuklewicz, Justin Bailey
maintainer: daniel.is.fischer@googlemail.com
homepage: https://bitbucket.org/dafis/stringsearch
synopsis: Fast searching, splitting and replacing of ByteStrings
description:
    This package provides several functions to quickly
    search for substrings in strict or lazy ByteStrings.
    It also provides functions for breaking or splitting
    on substrings and replacing all occurrences of a
    substring (the first in case of overlaps) with another.
    GHC before 6.10 are no longer supported, other compilers
    only if they support BangPatterns. If you need it to
    work with other compilers, send a feature request.
category: Text, Search
author: Daniel Fischer, Chris Kuklewicz, Justin Bailey
exposed: True
indefinite: False
exposed-modules:
    Data.ByteString.Lazy.Search Data.ByteString.Lazy.Search.DFA
    Data.ByteString.Lazy.Search.KMP
    Data.ByteString.Lazy.Search.KarpRabin Data.ByteString.Search
    Data.ByteString.Search.BoyerMoore Data.ByteString.Search.DFA
    Data.ByteString.Search.KMP Data.ByteString.Search.KarpRabin
    Data.ByteString.Search.KnuthMorrisPratt
    Data.ByteString.Search.Substitution
hidden-modules: Data.ByteString.Search.Internal.BoyerMoore
                Data.ByteString.Search.Internal.KnuthMorrisPratt
                Data.ByteString.Search.Internal.Utils
                Data.ByteString.Lazy.Search.Internal.BoyerMoore
abi: ad8df4d60dd590f7c73e1ab245c06a55
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/stringsearch-0.3.6.6
library-dirs: /usr/lib/ghc-8.2.2/site-local/stringsearch-0.3.6.6
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/stringsearch-0.3.6.6
hs-libraries: HSstringsearch-0.3.6.6-5wkiVsEYY78BZshzFV6bBe
depends:
    array-0.5.2.0 base-4.10.1.0 bytestring-0.10.8.2 containers-0.5.10.2
abi-depends: array-0.5.2.0=26dc06837667b4f45ea7fe07c114ff89
             base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             bytestring-0.10.8.2=4a9e2cf748f0e2cc5be33be7a5505ecf
             containers-0.5.10.2=cc49645af4ed58d1819a7e09ee1f7920
haddock-interfaces: /usr/share/doc/haskell-stringsearch/html/stringsearch.haddock
haddock-html: /usr/share/doc/haskell-stringsearch/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
